#! /bin/sh

eval $(dbus export unblockmusic)
source /koolshare/scripts/base.sh

alias echo_date='echo 【$(TZ=UTC-8 date -R +%Y年%m月%d日\ %X)】:'
MODEL=$(nvram get productid)


mkdir -p /tmp/upload
sleep 2s

# 判断路由架构和平台
case $(uname -m) in
	armv7l)
		echo_date 固件平台【koolshare merlin armv7l】符合安装要求，开始安装插件！
	;;
	*)
		echo_date 本插件适用于koolshare merlin armv7l固件平台，你的平台"$(uname -m)"不能安装！！！
		echo_date 退出安装！
		exit 1
	;;
esac

# 低于7.2的固件不能安装
firmware_version=`nvram get extendno|cut -d "X" -f2|cut -d "-" -f1|cut -d "_" -f1`
firmware_comp=`versioncmp $firmware_version 7.2`
if [ "$firmware_comp" == "1" ];then
	echo_date 本插件不支持X7.2以下的固件版本，当前固件版本$firmware_version，请更新固件！
	echo_date 退出安装！
	exit 1
fi


enable=`dbus get unblockmusic_enable`
#升级前先删除无关文件,保留已上传配置文件
# 检测储存空间是否足够
echo_date 检测jffs分区剩余空间...
SPACE_AVAL=$(df|grep jffs | awk '{print $4}')
SPACE_NEED=$(du -s /tmp/unblockmusic | awk '{print $1}')
if [ "$SPACE_AVAL" -gt "$SPACE_NEED" ];then
	echo_date 当前jffs分区剩余"$SPACE_AVAL" KB, 插件安装需要"$SPACE_NEED" KB，空间满足，继续安装！
	# 先关闭clash
	if [ "$enable" == "1" ];then
		echo_date 先关闭网易云解锁插件，保证文件更新成功!
		[ -f "/koolshare/unmusic/unblockmusicconfig.sh" ] && sh /koolshare/unmusic/unblockmusicconfig.sh stop
	fi
	echo_date 清理旧文件
	rm -rf /koolshare/unmusic
	rm -rf /koolshare/bin/UnblockNeteaseMusic
	rm -rf /koolshare/bin/Music
	rm -rf /koolshare/webs/Module_unblockmusic*
	rm -rf /koolshare/res/icon-unblockmusic.png
	rm -rf /koolshare/res/unblock.png
	rm -rf /koolshare/res/musicCN.json
	rm -rf /koolshare/res/musicEN.json
	rm -rf /koolshare/res/musicTW.json
	rm -rf /koolshare/res/unblockmusic*
	rm -rf /koolshare/scripts/unblockmusic*

	find /koolshare/init.d/ -name "*unblockmusic.sh" | xargs rm -rf
	echo_date 开始复制文件！
	mkdir -p /koolshare/unmusic
	cd /tmp

	echo_date 复制相关二进制文件！此步时间可能较长！
	cp -rf /tmp/unblockmusic/bin/* /koolshare/bin/

	echo_date 复制相关的脚本文件！
	cp -rf /tmp/unblockmusic/scripts/* /koolshare/scripts/
	cp -rf /tmp/unblockmusic/install.sh /koolshare/scripts/unblockmusic_install.sh
	cp -rf /tmp/unblockmusic/uninstall.sh /koolshare/scripts/uninstall_unblockmusic.sh
	
	echo_date 复制相关的网页文件！
	cp -rf /tmp/unblockmusic/webs/* /koolshare/webs/
	cp -rf /tmp/unblockmusic/res/* /koolshare/res/
	cp -rf /tmp/unblockmusic/unmusic/* /koolshare/unmusic/
	cp -rf /tmp/unblockmusic/version /koolshare/unmusic/
	echo_date 为新安装文件赋予执行权限...
	chmod 755 /koolshare/bin/UnblockNeteaseMusic
	chmod 755 /koolshare/unmusic/*
	chmod 755 /koolshare/scripts/unblockmusic*
	chmod 755 /koolshare/res/unblockmusic*

	echo_date "创建自启脚本软链接！"
	[ -L "/koolshare/init.d/S99unblockmusic.sh" ] && rm -rf /koolshare/init.d/S99unblockmusic.sh && ln -sf /koolshare/unmusic/unblockmusicconfig.sh /koolshare/init.d/S99unblockmusic.sh
	[ -L "/koolshare/init.d/N99unblockmusic.sh" ] && rm -rf /koolshare/init.d/N99unblockmusic.sh && ln -sf /koolshare/unmusic/unblockmusicconfig.sh /koolshare/init.d/N99unblockmusic.sh
	[ ! -L "/koolshare/init.d/S99unblockmusic.sh" ]  && ln -sf /koolshare/unmusic/unblockmusicconfig.sh /koolshare/init.d/S99unblockmusic.sh
	[ ! -L "/koolshare/init.d/N99unblockmusic.sh" ]  && ln -sf /koolshare/unmusic/unblockmusicconfig.sh /koolshare/init.d/N99unblockmusic.sh
	# 离线安装时设置软件中心内储存的版本号和连接

	echo_date 设置相关参数初始值！
	CUR_VERSION=$(cat /koolshare/unmusic/version)
	dbus set unblockmusic_version="$CUR_VERSION"
	dbus set softcenter_module_unblockmusic_version="$CUR_VERSION"
	dbus set softcenter_module_unblockmusic_description="解锁网易云灰色歌曲"
	dbus set softcenter_module_unblockmusic_install=1
	dbus set softcenter_module_unblockmusic_name=unblockmusic
	dbus set softcenter_module_unblockmusic_title="解锁网易云灰色歌曲"
	[ -z "$unblockmusic_musicapptype" ] && dbus set unblockmusic_musicapptype='default'
	[ -z "$unblockmusic_endpoint" ] && dbus set unblockmusic_endpoint='https://music.163.com'
	dbus set unblockmusic_UnblockNeteaseMusic_version=`/koolshare/bin/UnblockNeteaseMusic -v |grep Version|awk '{print $2}'`



	echo_date 一点点清理工作...
	rm -rf /tmp/unblockmusic* >/dev/null 2>&1

	echo_date 网易云解锁插件安装成功！
	if [ "$enable" == "1" ] && [ -f "/koolshare/unmusic/unblockmusicconfig.sh" ];then
		/koolshare/unmusic/unblockmusicconfig start >/dev/null 2>&1
	fi
	echo_date 更新完毕，请等待网页自动刷新！
else
	echo_date 当前jffs分区剩余"$SPACE_AVAL" KB, 插件安装需要"$SPACE_NEED" KB，空间不足！
	echo_date 退出安装！
	exit 1
fi

