#!/bin/sh

source /koolshare/scripts/base.sh
eval `dbus export unblockmusic_`
alias echo_date='echo 【$(TZ=UTC-8 date -R +%Y年%m月%d日\ %X)】:'
LOGFILE="/tmp/unmusic.log"
echo_date "测试脚本写入" >> $LOGFILE
ROUTE_IP=$(nvram get lan_ipaddr)
ipt_n="iptables -t nat"
serverCrt="/koolshare/bin/Music/server.crt"
serverKey="/koolshare/bin/Music/server.key"
ipset_music=$(ipset list umusic)

create_autostart(){
	if [ ! -L "/koolshare/init.d/S97unblockmusic.sh" ];then
		ln -sf /koolshare/scripts/unblockmusic_config.sh /koolshare/init.d/S97unblockmusic.sh
	fi
	if [ ! -L "/koolshare/init.d/N97unblockmusic.sh" ];then
		ln -sf /koolshare/scripts/unblockmusic_config.sh /koolshare/init.d/N97unblockmusic.sh
	fi
}

remove_autostart(){
	rm -f /koolshare/init.d/*unblockmusic.sh
}

add_rule()
{
	echo_date 加载网易云音乐解锁nat规则... >> $LOGFILE
	if [ -n "$ipset_music" ]; then
		echo_date "已存在ipset规则" >> $LOGFILE
	else
		ipset -! -N umusic hash:ip
		ipset add umusic 59.111.181.60 
		ipset add umusic 59.111.181.38 
		ipset add umusic 59.111.181.35 
		ipset add umusic 59.111.160.195
		ipset add umusic 223.252.199.66
		ipset add umusic 59.111.160.197
		ipset add umusic 223.252.199.67
		ipset add umusic 115.236.121.1
		ipset add umusic 115.236.121.3
		ipset add umusic 115.236.118.33
		ipset add umusic 39.105.63.80
		ipset add umusic 118.24.63.156
		ipset add umusic 193.112.159.225
		ipset add umusic 47.100.127.239
		#20200712++++
		ipset add umusic 112.13.122.1
		ipset add umusic 112.13.119.17
		ipset add umusic 103.126.92.133
		ipset add umusic 103.126.92.132
		ipset add umusic 101.71.154.241
		ipset add umusic 59.111.238.29/
		ipset add umusic 59.111.179.214
		ipset add umusic 59.111.21.14
		ipset add umusic 45.254.48.1
		ipset add umusic 42.186.120.199
	fi
	#20200712----
	$ipt_n -N cloud_umusic
	$ipt_n -A cloud_umusic -d 0.0.0.0/8 -j RETURN
	$ipt_n -A cloud_umusic -d 10.0.0.0/8 -j RETURN
	$ipt_n -A cloud_umusic -d 127.0.0.0/8 -j RETURN
	$ipt_n -A cloud_umusic -d 169.254.0.0/16 -j RETURN
	$ipt_n -A cloud_umusic -d 172.16.0.0/12 -j RETURN
	$ipt_n -A cloud_umusic -d 192.168.0.0/16 -j RETURN
	$ipt_n -A cloud_umusic -d 224.0.0.0/4 -j RETURN
	$ipt_n -A cloud_umusic -d 240.0.0.0/4 -j RETURN
	$ipt_n -A cloud_umusic -p tcp --dport 80 -j REDIRECT --to-ports 5200
	$ipt_n -A cloud_umusic -p tcp --dport 443 -j REDIRECT --to-ports 5300
	$ipt_n -I PREROUTING -p tcp -m set --match-set umusic dst -j cloud_umusic
	iptables -I OUTPUT -d 223.252.199.10 -j DROP
}

del_rule(){
	echo_date 移除网易云音乐解锁nat规则... >> $LOGFILE
	$ipt_n -D PREROUTING -p tcp -m set --match-set music dst -j cloud_umusic >/dev/null 2>&1 
	iptables -D OUTPUT -d 223.252.199.10 -j DROP >/dev/null 2>&1 
	$ipt_n -F cloud_umusic  >/dev/null 2>&1 
	$ipt_n -X cloud_umusic  >/dev/null 2>&1 	
	rm -f /tmp/etc/dnsmasq.user/dnsmasq-music.conf
	service restart_dnsmasq
}

set_firewall(){

	rm -f /tmp/etc/dnsmasq.user/dnsmasq-umusic.conf
	#echo "ipset=/music.163.com/music" >> /tmp/etc/dnsmasq.user/dnsmasq-music.conf #20200524
	echo "ipset=/.music.163.com/music" >> /tmp/etc/dnsmasq.user/dnsmasq-umusic.conf
	echo "ipset=/interface.music.163.com/music" >> /tmp/etc/dnsmasq.user/dnsmasq-umusic.conf
	echo "ipset=/interface3.music.163.com/music" >> /tmp/etc/dnsmasq.user/dnsmasq-umusic.conf
	echo "ipset=/apm.music.163.com/music" >> /tmp/etc/dnsmasq.user/dnsmasq-umusic.conf
	echo "ipset=/apm3.music.163.com/music" >> /tmp/etc/dnsmasq.user/dnsmasq-umusic.conf
	echo "ipset=/clientlog.music.163.com/music" >> /tmp/etc/dnsmasq.user/dnsmasq-umusic.conf
	echo "ipset=/clientlog3.music.163.com/music" >> /tmp/etc/dnsmasq.user/dnsmasq-umusic.conf
	service restart_dnsmasq
	add_rule
}
remove_unblock_restart_job(){
	if [ -n "$(cru l|grep unblock_restart)" ]; then
		echo_date "删除网易云音乐解锁自动重启定时任务..." >> $LOGFILE
		sed -i '/unblock_restart/d' /var/spool/cron/crontabs/* >/dev/null 2>&1
	fi
}

start_unblock_restart_job_day(){
	remove_unblock_restart_job
	echo_date "创建网易云音乐解锁自动重启定时任务..." >> $LOGFILE
	cru a unblock_restart ${unblockmusic_select_minute} ${unblockmusic_select_hour}" * * * /bin/sh /koolshare/scripts/unblockmusic_config.sh restart"
}
start_unblock_restart_job_week(){
	remove_unblock_restart_job
	echo_date "创建网易云音乐解锁自动重启定时任务..." >> $LOGFILE
	cru a unblock_restart ${unblockmusic_select_minute} ${unblockmusic_select_hour}" * * "${unblockmusic_select_week}" /bin/sh /koolshare/scripts/unblockmusic_config.sh restart"
}
start_unblock_restart_job_month(){
	remove_unblock_restart_job
	echo_date "创建网易云音乐解锁自动重启定时任务..." >> $LOGFILE
	cru a unblock_restart ${unblockmusic_select_minute} ${unblockmusic_select_hour} ${unblockmusic_select_day}" * * /bin/sh /koolshare/scripts/unblockmusic_config.sh restart"

}

start_unblock_restart_job(){
	case $unblockmusic_select_job in
	1)
		remove_unblock_restart_job
		;;
	2)
		start_unblock_restart_job_day
		;;
	3)
		start_unblock_restart_job_week
		;;
	4)
		start_unblock_restart_job_month
		;;
	esac
}
start_unblockmusic(){
	rm -rf /tmp/unmusic.log
	echo_date "开启网易云音乐解锁功能" >> $LOGFILE
	
	stop_unblockmusic
	remove_unblock_restart_job

	if [ $unblockmusic_enable -eq 0 ]; then
		echo_date "解锁开关未开启，退出" >> $LOGFILE
		exit 0
	fi
	endponintset="";
	if [ -n "$unblockmusic_endpoint" ]; then
		endponintset="-e"
	fi
	ver="0.2.5"
	echo_date "当前二进制版本为$unblockmusic_UnblockNeteaseMusic_version" >> $LOGFILE
	COMP=$(versioncmp $unblockmusic_UnblockNeteaseMusic_version $ver)

	if [ "$COMP" == "-1" ] || [ "$COMP" == "0" ]  ; then
		echo_date "当前版本可开启显示搜索结果数：$unblockmusic_platforms_numbers" >> $LOGFILE
		if [ "$unblockmusic_musicapptype" == "default" ]; then
			if [ "$unblockmusic_bestquality" == "1" ]; then
				/koolshare/bin/UnblockNeteaseMusic -p 5200 -sp 5300 -m 0 -sl "${unblockmusic_platforms_numbers}" -c "${serverCrt}" -k "${serverKey}" "${endponintset}" -b >/dev/null 2>&1 &
			else
				/koolshare/bin/UnblockNeteaseMusic -p 5200 -sp 5300 -m 0 -sl "${unblockmusic_platforms_numbers}" -c "${serverCrt}" -k "${serverKey}" "${endponintset}" >/dev/null 2>&1 &
			fi
		
		else
			if [ "$unblockmusic_bestquality" == "1" ]; then
				/koolshare/bin/UnblockNeteaseMusic -p 5200 -sp 5300 -o "$unblockmusic_musicapptype" -m 0 -sl "${unblockmusic_platforms_numbers}" -c "${serverCrt}" -k "${serverKey}" "${endponintset}" -b >/dev/null 2>&1 &
			else
				/koolshare/bin/UnblockNeteaseMusic -p 5200 -sp 5300 -o "$unblockmusic_musicapptype" -m 0 -sl "${unblockmusic_platforms_numbers}" -c "${serverCrt}" -k "${serverKey}" "${endponintset}" >/dev/null 2>&1 &
			fi
		fi
	else
		echo_date "当前版本不可开启显示搜索结果数" >> $LOGFILE
		if [ "$unblockmusic_musicapptype" == "default" ]; then
			if [ "$unblockmusic_bestquality" == "1" ]; then
				/koolshare/bin/UnblockNeteaseMusic -p 5200 -sp 5300 -m 0 -c "${serverCrt}" -k "${serverKey}" "${endponintset}" -b >/dev/null 2>&1 &
			else
				/koolshare/bin/UnblockNeteaseMusic -p 5200 -sp 5300 -m 0 -c "${serverCrt}" -k "${serverKey}" "${endponintset}" >/dev/null 2>&1 &
			fi
		
		else
			if [ "$unblockmusic_bestquality" == "1" ]; then
				/koolshare/bin/UnblockNeteaseMusic -p 5200 -sp 5300 -o "$unblockmusic_musicapptype" -m 0 -c "${serverCrt}" -k "${serverKey}" "${endponintset}" -b >/dev/null 2>&1 &
			else
				/koolshare/bin/UnblockNeteaseMusic -p 5200 -sp 5300 -o "$unblockmusic_musicapptype" -m 0 -c "${serverCrt}" -k "${serverKey}" "${endponintset}" >/dev/null 2>&1 &
			fi
		
		fi
		
	fi
	echo_date "设置相关iptable规则" >> $LOGFILE
	set_firewall
	ubm_process=$(pidof UnblockNeteaseMusic);
	if [ -n "$ubm_process" ]; then
		echo_date "网易云音乐解锁启动完成，pid：$ubm_process" >> $LOGFILE
		start_unblock_restart_job
	fi
	create_autostart
}

stop_unblockmusic(){
	kill -9 $(busybox ps -w | grep UnblockNeteaseMusic | grep -v grep | awk '{print $1}') >/dev/null 2>&1
	rm -f /tmp/unblockmusic.log

	del_rule
	remove_unblock_restart_job
#	remove_autostart
}

case $ACTION in
start)
	if [ "$unblockmusic_enable" == "1" ]; then
		echo_date "开启网易云音乐解锁" >> $LOGFILE
		start_unblockmusic
	fi
	;;
restart)
	if [ "$unblockmusic_enable" == "1" ]; then
		echo_date "开启网易云音乐解锁" >> $LOGFILE
		start_unblockmusic
	fi
	;;
stop)
	echo_date "关闭网易云音乐解锁" >> $LOGFILE
	stop_unblockmusic
	;;
*)
	if [ "$unblockmusic_enable" == "1" ]; then
		start_unblockmusic
	else
		stop_unblockmusic
	fi
	;;
esac

